@@ -3,12 +3,12 @@
 from urllib.parse import urljoin
 
 __project__ = "xarg-python"
-__version__ = "1.6"
+__version__ = "1.6.3"
 __description__ = "Simple command-line tool based on argparse."
-__url_home__ = "https://github.com/bondbox/xarg-python/"
-__url_code__ = __url_home__
-__url_docs__ = __url_home__
-__url_bugs__ = urljoin(__url_home__, "issues")
+__urlhome__ = "https://github.com/bondbox/xarg-python/"
+__urlcode__ = __urlhome__
+__urldocs__ = __urlhome__
+__urlbugs__ = urljoin(__urlhome__, "issues")
 
 # author
 __author__ = "Mingzhe Zou"
