@@ -3,18 +3,6 @@
 import os
 from typing import List
 
-from .attribute import __author__
-from .attribute import __author_email__
-from .attribute import __description__
-from .attribute import __prog_complete__
-from .attribute import __prog_name__
-from .attribute import __project__
-from .attribute import __url_bugs__
-from .attribute import __url_code__
-from .attribute import __url_docs__
-from .attribute import __url_home__
-from .attribute import __version__
-
 
 def singleton(cls):
     instance = {}
